integration

package
v0.1.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 13, 2026 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Overview

Package integration provides utilities for integration testing of AI providers. These tests make actual API calls and require valid API keys.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func SkipIfNoKey

func SkipIfNoKey(t *testing.T, envVar string)

SkipIfNoKey skips the test if the specified environment variable is not set.

func TestEmbed

func TestEmbed(t *testing.T, m model.EmbeddingModel)

TestEmbed tests single embedding generation.

func TestEmbedMany

func TestEmbedMany(t *testing.T, m model.EmbeddingModel)

TestEmbedMany tests multiple embedding generation.

func TestGenerateImage

func TestGenerateImage(t *testing.T, m model.ImageModel)

TestGenerateImage tests image generation.

func TestGenerateSpeech

func TestGenerateSpeech(t *testing.T, m model.SpeechModel)

TestGenerateSpeech tests text-to-speech generation.

func TestGenerateText

func TestGenerateText(t *testing.T, m stream.Model)

TestGenerateText tests basic text generation.

func TestGenerateTextWithSystemPrompt

func TestGenerateTextWithSystemPrompt(t *testing.T, m stream.Model)

TestGenerateTextWithSystemPrompt tests text generation with a system prompt.

func TestImageInput

func TestImageInput(t *testing.T, m stream.Model, imageURL string)

TestImageInput tests image input for vision models.

func TestStreamText

func TestStreamText(t *testing.T, m stream.Model)

TestStreamText tests streaming text generation.

func TestToolCalls

func TestToolCalls(t *testing.T, m stream.Model)

TestToolCalls tests tool calling functionality.

func TestTranscribe

func TestTranscribe(t *testing.T, m model.TranscriptionModel, audioData []byte)

TestTranscribe tests speech-to-text transcription.

Types

This section is empty.

Jump to